==> opennms-config-19.0.0-20161118.232803-308-sources.jar: org/opennms/netmgt/config/RangeComparator.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.config;

import java.io.Serializable;
import java.net.InetAddress;
import java.util.Comparator;

import org.opennms.core.utils.ByteArrayComparator;
import org.opennms.core.utils.InetAddressUtils;
import org.opennms.netmgt.config.snmp.Range;

/**
 * Use this class to compare two castor generated Range objects from the SnmpConfig class.
 *
 * @author <a href="mailto:david@opennms.org">David Hustace</a>
 */
public class RangeComparator implements Comparator<Range>, Serializable {
	private static final long serialVersionUID = -6090811413071744038L;

	/**
     * <p>compare</p>
     *
     * @param rng1 a {@link org.opennms.netmgt.config.common.Range} object.
     * @param rng2 a {@link org.opennms.netmgt.config.common.Range} object.
     * @return a int.
     */
        @Override
    public int compare(final Range rng1, final Range rng2) {
    	final InetAddress addr1 = InetAddressUtils.addr(rng1.getBegin());
		final InetAddress addr2 = InetAddressUtils.addr(rng2.getBegin());
		return new ByteArrayComparator().compare(addr1 == null? null : addr1.getAddress(), addr2 == null? null : addr2.getAddress());
    }
}

==> opennms-config-27.0.0-20200522.210116-28-sources.jar: org/opennms/netmgt/config/RangeComparator.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.config;

import java.io.Serializable;
import java.net.InetAddress;
import java.util.Comparator;

import org.opennms.core.utils.ByteArrayComparator;
import org.opennms.core.utils.InetAddressUtils;
import org.opennms.netmgt.config.snmp.Range;

/**
 * Use this class to compare two JAXB-generated Range objects from the SnmpConfig class.
 *
 * @author <a href="mailto:david@opennms.org">David Hustace</a>
 */
public class RangeComparator implements Comparator<Range>, Serializable {
	private static final long serialVersionUID = -6090811413071744038L;

	/**
     * <p>compare</p>
     *
     * @param rng1 a {@link org.opennms.netmgt.config.common.Range} object.
     * @param rng2 a {@link org.opennms.netmgt.config.common.Range} object.
     * @return a int.
     */
        @Override
    public int compare(final Range rng1, final Range rng2) {
    	final InetAddress addr1 = InetAddressUtils.addr(rng1.getBegin());
		final InetAddress addr2 = InetAddressUtils.addr(rng2.getBegin());
		return new ByteArrayComparator().compare(addr1 == null? null : addr1.getAddress(), addr2 == null? null : addr2.getAddress());
    }
}
